<?php

/**
 * @file
 * Development Roles Users common functions.
 */

/**
 * Gets user information for each role.
 */
function dev_roles_users_get_users_info() {
  global $base_url;
  $users = array();
  $roles = user_roles(TRUE);

  // Remove "authenticated user" form the roles list.
  unset($roles[DRUPAL_AUTHENTICATED_RID]);

  // Clean $base_url to be used as email domain.
  $mail_domain = preg_replace('#http(s)?://(www.)?#', '', $base_url);

  foreach ($roles as $rid => $role) {
    $username = dev_roles_users_get_clean_username($role);
    $mail = $username . '@' . $mail_domain;

    $user = [
      'name' => $username,
      'pass' => $username,
      'mail' => $mail,
      'status' => 1,
      'roles' => [
        DRUPAL_AUTHENTICATED_RID => 'authenticated user',
        $rid => $role,
      ],
    ];

    if (module_exists('uuid')) {
      $user['uuid'] = dev_roles_users_generate_user_uuid($username);
    }

    $users[] = $user;
  }

  return $users;
}

/**
 * Gets clean username from role name.
 */
function dev_roles_users_get_clean_username($role) {
  return strtolower(preg_replace('/[\s]+/', '.', $role));
}

/**
 * Generates a version 5 UUID for a given username.
 *
 * @param string $username
 *   The username used to generate the UUID.
 *
 * @return string
 *   The UUID represented a string.
 */
function dev_roles_users_generate_user_uuid($username) {

  module_load_include('inc', 'uuid');

  // URL namespace UUID is defined in Appendix C of RFC 4412.
  $url_namespace_uuid = '6ba7b811-9dad-11d1-80b4-00c04fd430c8';

  // The URL format is something skwashd made up to ensure we have something
  // that is unique. The UUID needs to be consistent for the same username
  // across multiple site instances or else deploy breaks.
  $url = "drupal_site://username/{$username}";

  return dev_roles_users_uuid_v5($url_namespace_uuid, $url);
}

/**
 * Generates a version 5 compliant UUID.
 *
 * @param string $namespace
 *   Namespace UUID as a hex encoded string.
 * @param string $name
 *   The name for the generating the UUID.
 *
 * @return string
 *   UUID as a hex encoded string.
 *
 * @fixme Remove this once it is in a stable UUID module release.
 *
 * @see uuid_generate_v5()
 */
function dev_roles_users_uuid_v5($namespace, $name) {
  if (!uuid_is_valid($namespace)) {
    return FALSE;
  }

  // Get hexadecimal components of namespace.
  $nhex = str_replace(array('-', '{', '}'), '', $namespace);

  // Binary Value.
  $nstr = '';

  // Convert Namespace UUID to bits.
  for ($i = 0; $i < strlen($nhex); $i += 2) {
    $nstr .= chr(hexdec($nhex[$i] . $nhex[$i + 1]));
  }

  // Calculate hash value.
  $hash = sha1($nstr . $name);

  return sprintf('%08s-%04s-%04x-%04x-%12s',

    // 32 bits for "time_low".
    substr($hash, 0, 8),

    // 16 bits for "time_mid".
    substr($hash, 8, 4),

    // 16 bits for "time_hi_and_version",
    // four most significant bits holds version number 5.
    (hexdec(substr($hash, 12, 4)) & 0x0fff) | 0x5000,

    // 16 bits, 8 bits for "clk_seq_hi_res",
    // 8 bits for "clk_seq_low",
    // two most significant bits holds zero and one for variant DCE1.1.
    (hexdec(substr($hash, 16, 4)) & 0x3fff) | 0x8000,

    // 48 bits for "node".
    substr($hash, 20, 12)
  );
}
